@@ -6,9 +6,17 @@ from .WebsocketListener import WebsocketListener
 
 class ZWaveMe:
     """Main controller class"""
-    def __init__(self, hass, config):
+    def __init__(self, hass, config, domain="" logger=None, platforms=None, zwaveplatforms=None, ):
         self._config = config
+        
+        if logger = None:
+            logger = logging.getLogger(__name__)
+        self._logger = logger
+
+        self.platforms = platforms
+        self.zwaveplatforms = zwaveplatforms
         self._hass = hass
+        self._domain = domain
         self._devices = []
         self.entities = {}
         self._ws = None
@@ -22,7 +30,7 @@ class ZWaveMe:
         self.thread = threading.Thread(target=self.init_websocket)
         self.thread.daemon = True
         self.thread.start()
-        _LOGGER.debug("STARTED THREAD")
+        self._logger.debug("STARTED THREAD")
 
     def send_command(self, device_id, command):
         self._ws.send(
@@ -50,7 +58,7 @@ class ZWaveMe:
     def init_websocket(self):
         # keep websocket open indefinitely
         while True:
-            _LOGGER.debug("(re)init websocket")
+            self._logger.debug("(re)init websocket")
             self._ws = WebsocketListener(
                 ZWaveMe=self,
                 on_message=self.on_message,
@@ -67,10 +75,10 @@ class ZWaveMe:
 
     def on_message(self, _, utf):
         if utf:
-            _LOGGER.debug("websocket msg: %s", utf)
+            self._logger.debug("websocket msg: %s", utf)
 
             dict_data = json.loads(utf)
-            _LOGGER.debug("websocket msg: %s", utf)
+            self._logger.debug("websocket msg: %s", utf)
             if "type" not in dict_data.keys():
                 return
             try:
@@ -80,13 +88,13 @@ class ZWaveMe:
                         self._devices = [
                             device
                             for device in body["data"]["devices"]
-                            if device["deviceType"] in ZWAVEPLATFORMS
+                            if device["deviceType"] in self.zwaveplatforms
                         ]
                         for device in self._devices:
                             _LOGGER.debug("CREATING DEVICE: %s", device)
                         if not self._configured:
                             self._hass.config_entries.async_setup_platforms(
-                                self._config, PLATFORMS
+                                self._config, self.platforms
                             )
                             self._configured = True
                 elif dict_data["type"] == "me.z-wave.devices.level":
@@ -103,20 +111,20 @@ class ZWaveMe:
                                     "metrics"
                                 ]["level"]
 
-                            if DOMAIN + "." + dict_data["data"]["id"] in self.entities:
+                            if self._domain + "." + dict_data["data"]["id"] in self.entities:
                                 self.entities[
-                                    DOMAIN + "." + dict_data["data"]["id"]
+                                    self._domain + "." + dict_data["data"]["id"]
                                 ].schedule_update_ha_state()
 
             except Exception as e:
-                _LOGGER.error("ERROR: %s", e)
+                self._logger.error("ERROR: %s", e)
 
     def on_error(self, *args, **kwargs):
         error = args[-1]
-        _LOGGER.error("websocket error: %s" % str(error))
+        self._logger.error("websocket error: %s" % str(error))
 
     def on_close(self, _, *args):
-        _LOGGER.debug("websocket closed")
+        self._logger.debug("websocket closed")
         for device in self._devices:
             device["visibility"] = False
         self._ws.connected = False
